
# File converter from h5 to tiff images

script or notebook version.

It gets as inputs the name to be used for saving the tiff files and a path to where the h5 file is.

It unpacks the h5 file and creates a folder with a single tiff file for each image present in the h5 file

